@@ -6,7 +6,7 @@ use vars qw( $VAL $W $MODE );
 
 use base 'Exporter';
 
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.36'; # VERSION
 
 our @EXPORT    = (qw( chmod getchmod )); ## no critic ( ProhibitAutomaticExportation )
 our @EXPORT_OK = (qw( symchmod lschmod getsymchmod getlschmod getmod ));
@@ -328,7 +328,7 @@ File::chmod - Implements symbolic and ls chmod modes
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -402,18 +402,18 @@ the modifying of a file's permissions without having to run a system call
 or determining the file's permissions, and then combining that with whatever
 bits are appropriate.  It also operates separately on each file.
 
-=head2 Functions
+=head1 FUNCTIONS - EXPORT
 
-Exported by default:
+=head2 chmod(MODE,FILES)
 
-=over 4
-
-=item chmod(MODE,FILES)
+Exported by Default
 
 Takes an octal, symbolic, or "ls" mode, and then chmods each file
 appropriately.
 
-=item getchmod(MODE,FILES)
+=head2 getchmod(MODE,FILES)
+
+Exported by Default
 
 Returns a list of modified permissions, without chmodding files.
 Accepts any of the three kinds of modes.
@@ -422,41 +422,33 @@ Accepts any of the three kinds of modes.
   # @newmodes holds the octal permissions of the files'
   # modes, if they were to be sent through chmod("+x"...)
 
-=back
+=head1 FUNCTIONS - EXPORT_OK
 
-Exported by request:
-
-=over 4
-
-=item symchmod(MODE,FILES)
+=head2 symchmod(MODE,FILES)
 
 Takes a symbolic permissions mode, and chmods each file.
 
-=item lschmod(MODE,FILES)
+=head2 lschmod(MODE,FILES)
 
 Takes an "ls" permissions mode, and chmods each file.
 
-=item getsymchmod(MODE,FILES)
+=head2 getsymchmod(MODE,FILES)
 
 Returns a list of modified permissions, without chmodding files.
 Accepts only symbolic permission modes.
 
-=item getlschmod(MODE,FILES)
+=head2 getlschmod(MODE,FILES)
 
 Returns a list of modified permissions, without chmodding files.
 Accepts only "ls" permission modes.
 
-=item getmod(FILES)
+=head2 getmod(FILES)
 
 Returns a list of the current mode of each file.
 
-=back
+=head1 VARIABLES
 
-=head2 Variables
-
-=over 4
-
-=item $File::chmod::DEBUG
+=head2 $File::chmod::DEBUG
 
 If set to a true value, it will report warnings, similar to those produced
 by chmod() on your system.  Otherwise, the functions will not report errors.
@@ -465,19 +457,17 @@ same time.  If $File::chmod::DEBUG is true, the function will report an
 error.  If not, you are not warned of the conflict.  It is set to 1 as
 default.
 
-=item $File::chmod::MASK
+=head2 $File::chmod::MASK
 
 Contains the umask to apply to new file modes when using getsymchmod().  This
 defaults to the return value of umask() at compile time.  Is only applied if
 $UMASK is true.
 
-=item $File::chmod::UMASK
+=head2 $File::chmod::UMASK
 
 This is a boolean which tells getsymchmod() whether or not to apply the umask
 found in $MASK.  It defaults to true.
 
-=back
-
 =for test_synopsis my ( @files );
 
 =head1 PORTING
